@@ -5,11 +5,18 @@ sys.path.append(os.path.dirname(__file__))
 import builder
 import webserver
 
+from __init__ import __version__
+
+
 @click.group('guttacli')
 @click.pass_context
 def cli(ctx):
     pass
 
+@cli.command('version')
+def command_version():
+    click.echo(__version__)
+
 @cli.command("create")
 def command_create():
     builder.create_website()
@@ -29,6 +36,12 @@ def command_go():
     webserver.run_webserver()
     click.echo("Server closed.")
 
+
+@cli.command('clean')
+def command_clean():
+    builder.clean_website()
+    
+
 def main():
     """A static website builder for webcomics!"""
     cli(prog_name="gutta")
